diff stringlengths 139 3.65k | message stringlengths 8 627 | diff_languages stringclasses 1
value |
|---|---|---|
diff --git a/pyoko/db/schema_update.py b/pyoko/db/schema_update.py
index <HASH>..<HASH> 100644
--- a/pyoko/db/schema_update.py
+++ b/pyoko/db/schema_update.py
@@ -13,7 +13,7 @@ from random import randint
from sys import stdout
import threading
import time
-from riak import ConflictError
+from riak import ConflictErr... | fixed issue #9 (schema creation breaks if bucket is new) | py |
diff --git a/httpagentparser/__init__.py b/httpagentparser/__init__.py
index <HASH>..<HASH> 100644
--- a/httpagentparser/__init__.py
+++ b/httpagentparser/__init__.py
@@ -262,6 +262,16 @@ class IPhone(Dist):
version = part.split(c)[0]
return version.replace('_', '.')
+class IPad(Dist... | iPad detection Added iPad detection (mimicking iPhone detection) | py |
diff --git a/discord/state.py b/discord/state.py
index <HASH>..<HASH> 100644
--- a/discord/state.py
+++ b/discord/state.py
@@ -312,9 +312,9 @@ class ConnectionState:
self.dispatch('channel_update', old_channel, channel)
def parse_channel_create(self, data):
- is_private = data.get('is_pri... | Handle private channel CHANNEL_CREATE better. | py |
diff --git a/lark/parsers/lalr_parser.py b/lark/parsers/lalr_parser.py
index <HASH>..<HASH> 100644
--- a/lark/parsers/lalr_parser.py
+++ b/lark/parsers/lalr_parser.py
@@ -66,9 +66,7 @@ class _Parser:
value_stack.append(value)
# Main LALR-parser loop
- try:
- token = next(stream... | Use loops for flow control instead of catching exceptions While optimizing hot spots in a tool I wrote I saw this issue. Changing this to use a for loop granted a minor speed boost to my script. | py |
diff --git a/digitalocean/Droplet.py b/digitalocean/Droplet.py
index <HASH>..<HASH> 100644
--- a/digitalocean/Droplet.py
+++ b/digitalocean/Droplet.py
@@ -237,7 +237,7 @@ class Droplet(BaseAPI):
return self.get_data(
"droplets/%s/actions/" % self.id,
type="POST",
- params={... | Set the "type" attribute to change_kernel | py |
diff --git a/pygccxml/declarations/container_traits.py b/pygccxml/declarations/container_traits.py
index <HASH>..<HASH> 100644
--- a/pygccxml/declarations/container_traits.py
+++ b/pygccxml/declarations/container_traits.py
@@ -229,9 +229,9 @@ class defaults_eraser(object):
return
value_type = c_... | Do not redefine tmpl variable with different type Fixes: Redefinition of tmpl type from str to string.Template (redefined-variable-type) | py |
diff --git a/box/test/flaky/_flaky_plugin.py b/box/test/flaky/_flaky_plugin.py
index <HASH>..<HASH> 100644
--- a/box/test/flaky/_flaky_plugin.py
+++ b/box/test/flaky/_flaky_plugin.py
@@ -6,8 +6,8 @@ from box.test.flaky.names import FlakyNames
from box.test.flaky.utils import unicode_type
+# pylint:disable=R0921
c... | Move pylint disable so Travis builds will stop failing. | py |
diff --git a/ykman/driver_u2f.py b/ykman/driver_u2f.py
index <HASH>..<HASH> 100644
--- a/ykman/driver_u2f.py
+++ b/ykman/driver_u2f.py
@@ -153,9 +153,17 @@ class U2FDriver(AbstractDriver):
except U2FHostError:
raise ModeSwitchError()
+ def close(self):
+ logger.debug('Close %s', self)
... | driver_u2f: improve closing of driver | py |
diff --git a/tornado/tcpserver.py b/tornado/tcpserver.py
index <HASH>..<HASH> 100644
--- a/tornado/tcpserver.py
+++ b/tornado/tcpserver.py
@@ -95,7 +95,7 @@ class TCPServer(object):
self._pending_sockets = []
self._started = False
self.max_buffer_size = max_buffer_size
- self.read_chun... | Fixed TCPServer not setting the correct read_chunk_size. | py |
diff --git a/test/test_transforms.py b/test/test_transforms.py
index <HASH>..<HASH> 100644
--- a/test/test_transforms.py
+++ b/test/test_transforms.py
@@ -335,6 +335,7 @@ class Tester(unittest.TestCase):
# Checking if Lambda can be printed as string
trans.__repr__()
+ @unittest.skipIf(stats is No... | add some scipy skip annotations to tests | py |
diff --git a/examples/hwapi/hwconfig_esp8266_esp12.py b/examples/hwapi/hwconfig_esp8266_esp12.py
index <HASH>..<HASH> 100644
--- a/examples/hwapi/hwconfig_esp8266_esp12.py
+++ b/examples/hwapi/hwconfig_esp8266_esp12.py
@@ -1,5 +1,5 @@
-from machine import Pin
+from machine import Pin, Signal
# ESP12 module as used b... | examples/hwapi: Use Signal for inverted LED on ESP-<I>. | py |
diff --git a/psaw/PushshiftAPI.py b/psaw/PushshiftAPI.py
index <HASH>..<HASH> 100644
--- a/psaw/PushshiftAPI.py
+++ b/psaw/PushshiftAPI.py
@@ -158,6 +158,8 @@ class PushshiftAPIMinimal(object):
except requests.ConnectionError:
continue
success = response.status_code == 200
+ ... | Warn about which non <I> code Warn about non-<I> codes. For example, I was getting a <I>: Url too long which including too many comment ids. | py |
diff --git a/combine/dev.py b/combine/dev.py
index <HASH>..<HASH> 100644
--- a/combine/dev.py
+++ b/combine/dev.py
@@ -61,6 +61,7 @@ class EventHandler(FileSystemEventHandler):
".cache",
".venv",
"env",
+ ".git",
)
for p in os.path.abspath(event_path... | Add .git to ignored dirs in dev event handler | py |
diff --git a/test/scheduler_visualisation_test.py b/test/scheduler_visualisation_test.py
index <HASH>..<HASH> 100644
--- a/test/scheduler_visualisation_test.py
+++ b/test/scheduler_visualisation_test.py
@@ -292,7 +292,7 @@ class SchedulerVisualisationTest(unittest.TestCase):
fail = dep_graph[BadReqTask(succe... | Fix test_dep_graph_missing_deps BadReqTask with deps() error is now scheduled but not run. This changes the values in the 'dep_graph' for the task: the 'params' field now contains the parameters passed to the task instead of the task_id. | py |
diff --git a/autopep8.py b/autopep8.py
index <HASH>..<HASH> 100755
--- a/autopep8.py
+++ b/autopep8.py
@@ -1650,7 +1650,6 @@ def _priority_key(pep8_result):
# We need to shorten lines last since the logical fixer can get in a
# loop, which causes us to exit early.
'e501',
- 'w503'
... | fix exception in fix_w<I>, when do not pointing out W<I> | py |
diff --git a/tests/test_copy.py b/tests/test_copy.py
index <HASH>..<HASH> 100644
--- a/tests/test_copy.py
+++ b/tests/test_copy.py
@@ -418,12 +418,19 @@ class TestCopyTo(tb.ConnectedTestCase):
)
f.seek(0)
+ if self.con.get_server_version() < (9, 4):
+ force_null = N... | Fix copy tests on PostgreSQL < <I> The force_null option was added in PostgreSQL <I> | py |
diff --git a/lib/nmpfit.py b/lib/nmpfit.py
index <HASH>..<HASH> 100644
--- a/lib/nmpfit.py
+++ b/lib/nmpfit.py
@@ -1340,9 +1340,9 @@ e.g. mpfit.status, mpfit.errmsg, mpfit.params, npfit.niter, mpfit.covar.
self.covar = numpy.zeros([nn, nn], numpy.float)
for i in range(n):
- ... | Fixed#<I> - Corrected a problem with covariance matrix not fully populated git-svn-id: <URL> | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -48,6 +48,7 @@ setup(
"Topic :: Software Development :: Libraries :: Python Modules",
"Topic :: Software Development :: Testing",
],
+ python_requires="~=3.5",
platforms="any",
include_packa... | Added explicit python version constraint in setup.py. This fixes #<I>. | py |
diff --git a/client/cli/ok.py b/client/cli/ok.py
index <HASH>..<HASH> 100644
--- a/client/cli/ok.py
+++ b/client/cli/ok.py
@@ -201,8 +201,12 @@ def main():
if isinstance(response, dict):
print("Backup successful for user: {0}".format(response['data']['email']))
- if args.s... | Show submission url for --backup | py |
diff --git a/createcoverage/script.py b/createcoverage/script.py
index <HASH>..<HASH> 100644
--- a/createcoverage/script.py
+++ b/createcoverage/script.py
@@ -49,7 +49,8 @@ def main():
parser.add_option("-t", "--test-args",
action="store", type="string", dest="test_args",
... | Added a little bit more documentation to --test-args | py |
diff --git a/backend/job_managers/local.py b/backend/job_managers/local.py
index <HASH>..<HASH> 100644
--- a/backend/job_managers/local.py
+++ b/backend/job_managers/local.py
@@ -26,7 +26,7 @@ class LocalJobManager(AbstractJobManager):
""" A Job Manager that starts and use a local agent """
def __init__(sel... | Forgot to update a constructor | py |
diff --git a/python_modules/dagster-graphql/dagster_graphql/schema/roots.py b/python_modules/dagster-graphql/dagster_graphql/schema/roots.py
index <HASH>..<HASH> 100644
--- a/python_modules/dagster-graphql/dagster_graphql/schema/roots.py
+++ b/python_modules/dagster-graphql/dagster_graphql/schema/roots.py
@@ -744,4 +74... | [dagster-graphql] handle norun_launcher | py |
diff --git a/saltant/client.py b/saltant/client.py
index <HASH>..<HASH> 100644
--- a/saltant/client.py
+++ b/saltant/client.py
@@ -38,8 +38,8 @@ class Client:
Example:
- >>> import saltant
- >>> client = saltant.Client(
+ >>> from saltant.client import Client
+ >>> client = Client(
... | Fix an autodated docstring example | py |
diff --git a/duct.py b/duct.py
index <HASH>..<HASH> 100644
--- a/duct.py
+++ b/duct.py
@@ -12,6 +12,7 @@ except ImportError:
class PurePath:
pass
+
# Public API
# ==========
@@ -486,6 +487,13 @@ def wants_input_writer(input_arg):
return isinstance(input_arg, (str, bytes))
+try:
+ # not d... | BrokenPipeError is IOError in Python 2 | py |
diff --git a/cnxpublishing/db.py b/cnxpublishing/db.py
index <HASH>..<HASH> 100644
--- a/cnxpublishing/db.py
+++ b/cnxpublishing/db.py
@@ -1241,10 +1241,9 @@ def _upsert_persons(cursor, person_ids, lookup_func):
# Check for existing records to update.
cursor.execute("SELECT personid from persons where personi... | removing unused exception b/c cursor.fetchall() will always return a list | py |
diff --git a/src/fuzzfetch/fetch.py b/src/fuzzfetch/fetch.py
index <HASH>..<HASH> 100644
--- a/src/fuzzfetch/fetch.py
+++ b/src/fuzzfetch/fetch.py
@@ -82,6 +82,7 @@ def _extract_file(zip_fp, info, path):
out_path = os.path.join(path, info.filename)
perm = info.external_attr >> 16
+ perm |= stat.S_IREAD ... | Make sure we don't set 0 permissions when extracting zips. | py |
diff --git a/previous_version.py b/previous_version.py
index <HASH>..<HASH> 100644
--- a/previous_version.py
+++ b/previous_version.py
@@ -1,4 +1,4 @@
-PREVIOUS_VERSION = '0.20.3'
+PREVIOUS_VERSION = '0.20.4'
def main(): | Store previous version [skip ci] | py |
diff --git a/tangelo/plugins/girder/control.py b/tangelo/plugins/girder/control.py
index <HASH>..<HASH> 100644
--- a/tangelo/plugins/girder/control.py
+++ b/tangelo/plugins/girder/control.py
@@ -3,11 +3,11 @@ import os
def setup(config, store):
- from girder.utility.server import setup_helper
+ from girder.u... | Bringing concise girder setup up-to-date with improvements in Girder. | py |
diff --git a/gmn/src/d1_gmn/app/middleware/view_handler.py b/gmn/src/d1_gmn/app/middleware/view_handler.py
index <HASH>..<HASH> 100644
--- a/gmn/src/d1_gmn/app/middleware/view_handler.py
+++ b/gmn/src/d1_gmn/app/middleware/view_handler.py
@@ -142,5 +142,5 @@ class ViewHandler:
def create_cors_options_response(se... | Fix: Local naming of BagIt zip archives and naming of contained objects | py |
diff --git a/klab/cluster_template/template-2.py b/klab/cluster_template/template-2.py
index <HASH>..<HASH> 100644
--- a/klab/cluster_template/template-2.py
+++ b/klab/cluster_template/template-2.py
@@ -499,7 +499,7 @@ def run_cluster(run_func):
if len(tasks_to_run) != 1:
print 'Running subtask %d... | Changing default to be to not try and move SGE output files | py |
diff --git a/fasteners/lock.py b/fasteners/lock.py
index <HASH>..<HASH> 100644
--- a/fasteners/lock.py
+++ b/fasteners/lock.py
@@ -110,7 +110,11 @@ class ReaderWriterLock(object):
This can be eventually removed if http://bugs.python.org/issue8800 ever
gets accepted into the python standard threading library..... | Add docstrings to reader/writer constants | py |
diff --git a/btfxwss/queue_processor.py b/btfxwss/queue_processor.py
index <HASH>..<HASH> 100644
--- a/btfxwss/queue_processor.py
+++ b/btfxwss/queue_processor.py
@@ -152,8 +152,12 @@ class QueueProcessor(Thread):
config = data
if 'pair' in config:
symbol = config['pair']
+ if ... | fixes #<I> by stripping preprended 't' We now strip any prepended 't's in symbols or pairs on channel_identifier creation. Hence it should be possible to use the usual symbols to get data via the client methods (BTCUSD, BTCEUR, etc). | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100755
--- a/setup.py
+++ b/setup.py
@@ -68,9 +68,8 @@ class retext_build(build):
class retext_sdist(sdist):
- sub_commands = sdist.sub_commands + [('build_translations', None)]
-
def run(self):
+ self.run_command('build_translations')
bundle_icons()
s... | setup.py: Make sure built .qm files are included in the tarball Entries in sub_commands are processed after the manifest is built, so that does not work. | py |
diff --git a/blockstack_client/config.py b/blockstack_client/config.py
index <HASH>..<HASH> 100644
--- a/blockstack_client/config.py
+++ b/blockstack_client/config.py
@@ -715,7 +715,6 @@ def read_config_file(config_path=CONFIG_PATH, set_migrate=False):
parser.set('blockstack-client', 'port', str(BLOCKSTACKD_PO... | no longer need storage_drivers_local config option | py |
diff --git a/harpoon/ship/syncer.py b/harpoon/ship/syncer.py
index <HASH>..<HASH> 100644
--- a/harpoon/ship/syncer.py
+++ b/harpoon/ship/syncer.py
@@ -78,6 +78,10 @@ class Syncer(object):
if not conf.image_index:
raise BadImage("Can't {0} without an image_index configuration".format(action), image... | Don't try and pull/push scratch | py |
diff --git a/km3pipe/db.py b/km3pipe/db.py
index <HASH>..<HASH> 100644
--- a/km3pipe/db.py
+++ b/km3pipe/db.py
@@ -367,7 +367,7 @@ class DBManager(object):
)
)
tcal = 0
- if not pcal:
+ if not pcal or np.isnan(pcal):
self.log.warning(
... | Apply suggestion to km3pipe/db.py | py |
diff --git a/brothon/analysis/dataframe_to_matrix.py b/brothon/analysis/dataframe_to_matrix.py
index <HASH>..<HASH> 100644
--- a/brothon/analysis/dataframe_to_matrix.py
+++ b/brothon/analysis/dataframe_to_matrix.py
@@ -107,6 +107,10 @@ class DataFrameToMatrix(object):
def _normalize_series(series):
smin =... | fix possible div by zero in normalization | py |
diff --git a/src/nupic/research/temporal_memory.py b/src/nupic/research/temporal_memory.py
index <HASH>..<HASH> 100644
--- a/src/nupic/research/temporal_memory.py
+++ b/src/nupic/research/temporal_memory.py
@@ -341,7 +341,12 @@ class TemporalMemory(object):
@param predictedInactiveCells (set) Indices... | Sort segments before iterating for compatibility with C++ | py |
diff --git a/trezor_agent/trezor/_factory.py b/trezor_agent/trezor/_factory.py
index <HASH>..<HASH> 100644
--- a/trezor_agent/trezor/_factory.py
+++ b/trezor_agent/trezor/_factory.py
@@ -5,12 +5,16 @@ def client():
# pylint: disable=import-error
from trezorlib.client import TrezorClient
from trezorlib.tr... | don't ask for passphrase (always use empty one similarly to TREZOR Connect) | py |
diff --git a/salt/pillar/stack.py b/salt/pillar/stack.py
index <HASH>..<HASH> 100644
--- a/salt/pillar/stack.py
+++ b/salt/pillar/stack.py
@@ -404,7 +404,7 @@ def _merge_dict(stack, obj):
def _merge_list(stack, obj):
strategy = 'merge-last'
- if isinstance(obj[0], dict) and '__' in obj[0]:
+ if obj and is... | Fix "IndexError: list index out of range" When running Python <I>, an empty list will throw an "IndexError: list index out of range" error. We must check if the list is not empty before trying to iterate over it. (backport <URL>) | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -1,4 +1,7 @@
from setuptools import setup
+from os import path
+
+readme = open(path.join(path.abspath(path.dirname(__file__)), 'README.md')).read()
setup(
name='bottle-websocket',
@@ -7,6 +10,6 @@ setup(
author_... | Get absolute path to README, fixes #2. | py |
diff --git a/mistletoe/latex_token.py b/mistletoe/latex_token.py
index <HASH>..<HASH> 100644
--- a/mistletoe/latex_token.py
+++ b/mistletoe/latex_token.py
@@ -1,6 +1,8 @@
import re
import mistletoe.span_token as span_token
+__all__ = ['Math']
+
class Math(span_token.SpanToken):
pattern = re.compile(r'((\${1,2... | 💡 added __all__ for latex_token | py |
diff --git a/pyknow/rete/nodes.py b/pyknow/rete/nodes.py
index <HASH>..<HASH> 100644
--- a/pyknow/rete/nodes.py
+++ b/pyknow/rete/nodes.py
@@ -9,11 +9,13 @@ needed in this implementation.
from collections.abc import Mapping
from contextlib import suppress
+from pyknow.activation import Activation
+from pyknow.rule ... | Added watcher to rete nodes | py |
diff --git a/i3pystatus/dota2wins.py b/i3pystatus/dota2wins.py
index <HASH>..<HASH> 100644
--- a/i3pystatus/dota2wins.py
+++ b/i3pystatus/dota2wins.py
@@ -42,6 +42,11 @@ class Dota2wins(IntervalModule):
def run(self):
api.set_api_key(self.steam_api_key)
+
+ if not isinstance(self.steamid, int):
+... | dota2wins: allow finding steam ID by username | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -18,7 +18,7 @@ from setuptools import find_packages, setup
setup(
name='gogo-utils',
- version='1.8',
+ version='1.8.1',
description='A utility library that generates service name convention details based on... | chore: Bump release to <I> | py |
diff --git a/cldoc/nodes/classtemplate.py b/cldoc/nodes/classtemplate.py
index <HASH>..<HASH> 100644
--- a/cldoc/nodes/classtemplate.py
+++ b/cldoc/nodes/classtemplate.py
@@ -18,10 +18,14 @@ from .templated import Templated
from cldoc.clang import cindex
class StructTemplate(Struct, Templated):
+ kind = None
+
... | Do not let templates override all function/methods | py |
diff --git a/xclim/subset.py b/xclim/subset.py
index <HASH>..<HASH> 100644
--- a/xclim/subset.py
+++ b/xclim/subset.py
@@ -1,4 +1,3 @@
-import copy
import logging
import warnings
from functools import wraps
@@ -458,11 +457,10 @@ def subset_shape(
"""
wgs84 = CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no... | Remove deepcopy from subset_shape | py |
diff --git a/dftimewolf/lib/processors/turbinia_gcp.py b/dftimewolf/lib/processors/turbinia_gcp.py
index <HASH>..<HASH> 100644
--- a/dftimewolf/lib/processors/turbinia_gcp.py
+++ b/dftimewolf/lib/processors/turbinia_gcp.py
@@ -171,7 +171,7 @@ class TurbiniaProcessorBase(module.BaseModule):
try:
evidence_.va... | Add missing str() (#<I>) | py |
diff --git a/tests/test_self.py b/tests/test_self.py
index <HASH>..<HASH> 100644
--- a/tests/test_self.py
+++ b/tests/test_self.py
@@ -399,8 +399,10 @@ class TestRunTC:
for key, value in expected.items():
assert key in message
assert message[key] == value
- assert "invalid synt... | Fix test failing because python <I> got better | py |
diff --git a/autofit/graphical/factor_graphs/abstract.py b/autofit/graphical/factor_graphs/abstract.py
index <HASH>..<HASH> 100644
--- a/autofit/graphical/factor_graphs/abstract.py
+++ b/autofit/graphical/factor_graphs/abstract.py
@@ -1,7 +1,7 @@
from abc import ABC, abstractmethod
from functools import wraps
from t... | changed typing as relying on index method | py |
diff --git a/pyisbn/__init__.py b/pyisbn/__init__.py
index <HASH>..<HASH> 100644
--- a/pyisbn/__init__.py
+++ b/pyisbn/__init__.py
@@ -172,7 +172,7 @@ class Isbn(object):
'advancedSearch.do?buttonClicked=2&isbn=%s' % self.isbn
elif site == 'whsmith':
return 'http://www.whsmith.co.... | [Tr] Wrapping fix. | py |
diff --git a/oauth2/store.py b/oauth2/store.py
index <HASH>..<HASH> 100644
--- a/oauth2/store.py
+++ b/oauth2/store.py
@@ -22,6 +22,15 @@ class AccessTokenStore(object):
"""
raise NotImplementedError
+
+ def fetch_by_refresh_token(self, refresh_token):
+ """
+ Fetches an... | Created method to fetch a refresh token | py |
diff --git a/awslimitchecker/tests/conftest.py b/awslimitchecker/tests/conftest.py
index <HASH>..<HASH> 100644
--- a/awslimitchecker/tests/conftest.py
+++ b/awslimitchecker/tests/conftest.py
@@ -47,6 +47,7 @@ Jason Antman <jason@jasonantman.com> <http://www.jasonantman.com>
import sys
import os
+import re
from _... | issue #<I> - conftest.py - sanitize MFA codes | py |
diff --git a/mock.py b/mock.py
index <HASH>..<HASH> 100644
--- a/mock.py
+++ b/mock.py
@@ -36,6 +36,11 @@ except ImportError:
inPy3k = sys.version_info[0] == 3
+if inPy3k:
+ class_types = (type,)
+else:
+ class_types = (type, types.ClassType)
+
# getsignature and mocksignature heavily "inspired" ... | Minor change to class decorator code. | py |
diff --git a/coinbase/client.py b/coinbase/client.py
index <HASH>..<HASH> 100644
--- a/coinbase/client.py
+++ b/coinbase/client.py
@@ -181,6 +181,13 @@ class Client(object):
'Could not parse API response')
return account
+ def redeem_token(self, tokenId):
+ data = encode_params({
+ ... | Added method call to redeem token. | py |
diff --git a/metnet/fastcore.py b/metnet/fastcore.py
index <HASH>..<HASH> 100644
--- a/metnet/fastcore.py
+++ b/metnet/fastcore.py
@@ -209,7 +209,7 @@ class Fastcore(object):
The largest consistent subset is returned as
a set of reaction names.'''
- return model.reaction_set - set(self.fastcc... | fastcore: Avoid creating new set in fastcc_consistent_subset | py |
diff --git a/tests/unit/utils/test_user.py b/tests/unit/utils/test_user.py
index <HASH>..<HASH> 100644
--- a/tests/unit/utils/test_user.py
+++ b/tests/unit/utils/test_user.py
@@ -18,11 +18,15 @@ from tests.support.unit import TestCase, skipIf
# Import Conditionals
try:
import grp
+
+ HAS_GRP = True
except Im... | Forgot to add variable for when import is successful | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100755
--- a/setup.py
+++ b/setup.py
@@ -111,7 +111,7 @@ def extensions():
language='c++',
libraries=[lib_prefix+'theobald'],
library_dirs=[mdtraj.capi()['lib_dir']],
- extra_compile_args=['-s... | back to cxx<I> | py |
diff --git a/src/scs_core/data/path_dict.py b/src/scs_core/data/path_dict.py
index <HASH>..<HASH> 100644
--- a/src/scs_core/data/path_dict.py
+++ b/src/scs_core/data/path_dict.py
@@ -13,8 +13,6 @@ from copy import deepcopy
from scs_core.data.json import JSONable
-# TODO: add node.remove(path)
-
# ----------------... | Added exclusion mode to node.py | py |
diff --git a/tile_generator/bosh.py b/tile_generator/bosh.py
index <HASH>..<HASH> 100644
--- a/tile_generator/bosh.py
+++ b/tile_generator/bosh.py
@@ -177,14 +177,6 @@ class BoshRelease:
mkdir_p(self.release_dir)
self.__bosh('init', 'release')
template.render(
- os.path.join(self.release_dir, 'src/templates/... | Removed unnecessary file from bosh release | py |
diff --git a/cathub/ase_tools/__init__.py b/cathub/ase_tools/__init__.py
index <HASH>..<HASH> 100755
--- a/cathub/ase_tools/__init__.py
+++ b/cathub/ase_tools/__init__.py
@@ -115,7 +115,8 @@ def collect_structures(foldername,
if inc_pattern:
if not np.any([pat in posix_filename for pat in ... | only print on verbose tricker | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100755
--- a/setup.py
+++ b/setup.py
@@ -30,17 +30,17 @@ version_re = re.compile(
r'__version__ = (\(.*?\))')
cwd = os.path.dirname(os.path.abspath(__file__))
-fp = open(os.path.join(cwd, 'yubico_client', '__init__.py'))
version = None
-for line in fp:
- ... | Make sure the file is always closed by using with context manager. | py |
diff --git a/riak/transports/feature_detect.py b/riak/transports/feature_detect.py
index <HASH>..<HASH> 100644
--- a/riak/transports/feature_detect.py
+++ b/riak/transports/feature_detect.py
@@ -24,7 +24,8 @@ versions = {
1: LooseVersion("1.0.0"),
1.1: LooseVersion("1.1.0"),
1.2: LooseVersion("1.2.0"),
-... | Add version <I> and detect for yz admin | py |
diff --git a/saltapi/netapi/rest_cherrypy/app.py b/saltapi/netapi/rest_cherrypy/app.py
index <HASH>..<HASH> 100644
--- a/saltapi/netapi/rest_cherrypy/app.py
+++ b/saltapi/netapi/rest_cherrypy/app.py
@@ -376,7 +376,7 @@ def yaml_processor(entity):
'''
body = entity.fp.read()
try:
- cherrypy.serving... | Run yaml.safe_load for yaml in the requst body | py |
diff --git a/spyder_kernels/comms/frontendcomm.py b/spyder_kernels/comms/frontendcomm.py
index <HASH>..<HASH> 100644
--- a/spyder_kernels/comms/frontendcomm.py
+++ b/spyder_kernels/comms/frontendcomm.py
@@ -128,6 +128,7 @@ class FrontendComm(CommBase):
if msg_type == 'shutdown_request':
self.com... | Close comm on shutdown If a shutdown message is recieved on the comm channel, close comm | py |
diff --git a/invenio_communities/communities/permissions.py b/invenio_communities/communities/permissions.py
index <HASH>..<HASH> 100644
--- a/invenio_communities/communities/permissions.py
+++ b/invenio_communities/communities/permissions.py
@@ -100,3 +100,5 @@ class CommunityPermissionPolicy(BasePermissionPolicy):
... | permissions: adds missing rename permission | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -51,7 +51,6 @@ setup(
'Programming Language :: Python :: 2.6', 'Programming Language :: Python :: 2.7',
'Programming Language :: Python :: 3', 'Programming Language :: Python :: 3.2',
... | Removed Jython from config file. | py |
diff --git a/pecan/core.py b/pecan/core.py
index <HASH>..<HASH> 100644
--- a/pecan/core.py
+++ b/pecan/core.py
@@ -157,13 +157,16 @@ class Pecan(object):
# get a sorted list of hooks, by priority (no controller hooks yet)
state.hooks = self.determine_hooks()
+
+ # store the ro... | Adding routing path so that the original URL is preserved when modified by hooks | py |
diff --git a/HardwareSource.py b/HardwareSource.py
index <HASH>..<HASH> 100644
--- a/HardwareSource.py
+++ b/HardwareSource.py
@@ -217,8 +217,9 @@ class HardwareSource(object):
try:
last_properties = None
new_data_elements = None
+ bad_frames = 0
- while True:
... | Made HardwareSource more resilient to dropped frames from sources. svn r<I> | py |
diff --git a/lenstronomy/Extensions/SimulationAPI/simulations.py b/lenstronomy/Extensions/SimulationAPI/simulations.py
index <HASH>..<HASH> 100644
--- a/lenstronomy/Extensions/SimulationAPI/simulations.py
+++ b/lenstronomy/Extensions/SimulationAPI/simulations.py
@@ -59,7 +59,7 @@ class Simulation(object):
# 'g... | fwhm to gaussian sigma conversion debugged in simulation API | py |
diff --git a/AlphaTwirl/Counter/GenericKeyComposer.py b/AlphaTwirl/Counter/GenericKeyComposer.py
index <HASH>..<HASH> 100755
--- a/AlphaTwirl/Counter/GenericKeyComposer.py
+++ b/AlphaTwirl/Counter/GenericKeyComposer.py
@@ -3,15 +3,15 @@
##____________________________________________________________________________||
... | remove "_" from variable names in GenericKeyComposer | py |
diff --git a/PyFunceble.py b/PyFunceble.py
index <HASH>..<HASH> 100755
--- a/PyFunceble.py
+++ b/PyFunceble.py
@@ -1795,6 +1795,7 @@ class Referer(object):
'bf',
'bh',
'bl',
+ 'bq',
'bs',
'cy',
'eg',
@@ -2666,7 +2667,7 @@ if __name... | Introduction of `bq` into the list of ignored extensions cf: No whois server. | py |
diff --git a/mysql/tests/conftest.py b/mysql/tests/conftest.py
index <HASH>..<HASH> 100644
--- a/mysql/tests/conftest.py
+++ b/mysql/tests/conftest.py
@@ -66,6 +66,8 @@ def dd_environment(config_e2e):
CheckDockerLogs('mysql-slave', ["ready for connections", "mariadb successfully initialized"]),
... | Add attempts to mysql environment (#<I>) * Add attempts to mysql environment | py |
diff --git a/arch/zx48k/translator.py b/arch/zx48k/translator.py
index <HASH>..<HASH> 100644
--- a/arch/zx48k/translator.py
+++ b/arch/zx48k/translator.py
@@ -478,7 +478,7 @@ class Translator(TranslatorVisitor):
def visit_LETARRAY(self, node):
- if self.O_LEVEL > 1 and not node.entry.accessed:
+ ... | Bugfix: Fix a bug in optimization for LETARRAY | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -23,7 +23,9 @@ class build_ext(build_ext_orig, object):
self.announce(message, level=log.INFO)
def run(self):
- if sys.version_info < (3, 4):
+ if sys.version_info >= (3, 4):
+ from pat... | pathlib imports on win don't hold | py |
diff --git a/src/foremast/plugin_manager.py b/src/foremast/plugin_manager.py
index <HASH>..<HASH> 100644
--- a/src/foremast/plugin_manager.py
+++ b/src/foremast/plugin_manager.py
@@ -1,4 +1,6 @@
"""Manager to handle plugins"""
+import pathlib
+
from pluginbase import PluginBase
@@ -11,7 +13,12 @@ class PluginMana... | refactor: PluginManager path begins at package root | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -207,8 +207,7 @@ def setup_xspec():
print("The xspec-modelsonly package has been installed in Conda. Xspec support will be installed")
# Set up the HEADAS variable so that the following will... | Now check for the presence of the xspec-modelsonly package in Conda and compile Xspec support if present | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -1,4 +1,5 @@
from setuptools import setup, find_packages
+from codecs import open
with open('README.rst', 'r', 'utf-8') as f:
readme = f.read() | Fixed open call in readme for use with 'long_description' | py |
diff --git a/sos/plugins/anacron.py b/sos/plugins/anacron.py
index <HASH>..<HASH> 100644
--- a/sos/plugins/anacron.py
+++ b/sos/plugins/anacron.py
@@ -21,7 +21,9 @@ class Anacron(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
plugin_name = 'anacron'
- packages = ('anacron',)
+ # anacron may be pr... | Replace package check with file check in anacron The anacron facility may be provided by packages named 'anacron', 'chronie-anacron' etc. They all use a common /etc/anacrontab file so check for this instead. | py |
diff --git a/plexapi/config.py b/plexapi/config.py
index <HASH>..<HASH> 100644
--- a/plexapi/config.py
+++ b/plexapi/config.py
@@ -62,4 +62,5 @@ def reset_base_headers():
'X-Plex-Device-Name': plexapi.X_PLEX_DEVICE_NAME,
'X-Plex-Client-Identifier': plexapi.X_PLEX_IDENTIFIER,
'X-Plex-Sync-Vers... | Enable external media in responses, e.g. Tidal (#<I>) | py |
diff --git a/pysat/tests/test_utils_testing.py b/pysat/tests/test_utils_testing.py
index <HASH>..<HASH> 100644
--- a/pysat/tests/test_utils_testing.py
+++ b/pysat/tests/test_utils_testing.py
@@ -190,7 +190,7 @@ class TestTestingUtils(object):
def test_prep_dir_new(self):
"""Test successful pass at creatin... | MAINT: fixed spelling Fixed spelling in test function. | py |
diff --git a/distob/arrays.py b/distob/arrays.py
index <HASH>..<HASH> 100644
--- a/distob/arrays.py
+++ b/distob/arrays.py
@@ -299,7 +299,13 @@ class DistArray(object):
def __repr__(self):
classname = self.__class__.__name__
- ix = tuple(np.meshgrid(*(((0, 1, -2, -1),)*self.ndim), indexing='ij'))... | fix __repr__ for small DistArray | py |
diff --git a/ctypeslib/codegen/cparser.py b/ctypeslib/codegen/cparser.py
index <HASH>..<HASH> 100644
--- a/ctypeslib/codegen/cparser.py
+++ b/ctypeslib/codegen/cparser.py
@@ -308,6 +308,13 @@ class IncludeParser(object):
if options.cpp_symbols:
if options.verbose:
+ print >> sys.s... | If cpp_symbols have to be generated, run gccxml first on the input files without generating anything. This is to check for compilation errors before doing the fancy stuff which may generate additional (and expected) compilation errors. git-svn-id: <URL> | py |
diff --git a/mib/reflash.py b/mib/reflash.py
index <HASH>..<HASH> 100644
--- a/mib/reflash.py
+++ b/mib/reflash.py
@@ -97,6 +97,9 @@ def analyze_stub(stub, proc):
mib_start = int(math.floor(mibblock[0]/proc.row_size))*proc.row_size
mib_end = mibblock[1]
+ if (highest_addr + 1) % proc.row_size != 0:
+ raise Value... | Add hextool - generic tool for hexfile manipulations Just like mibtool, modtool and pcbtool, hextool is a swiss-army knife but this time for manipulating hex files corresponding to pic<I> code. It can merge, compare, insert and patch pic<I> hex files using routines from pymomo so that they're accessible programmatica... | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100755
--- a/setup.py
+++ b/setup.py
@@ -31,7 +31,9 @@ setup(
],
include_package_data=True,
install_requires=[
- 'Django>=1.11,<2.2',
+ 'Django==1.11;python_version<"3.0"',
+ 'Django>=1.11,<2.1;python_version<"3.5"',
+ 'Dja... | make clear what django version is required for the current python | py |
diff --git a/riscvmodel/isa.py b/riscvmodel/isa.py
index <HASH>..<HASH> 100644
--- a/riscvmodel/isa.py
+++ b/riscvmodel/isa.py
@@ -533,7 +533,7 @@ class InstructionJType(Instruction, metaclass=ABCMeta):
"""
field_rd = Field(name="rd", base=7, size=5, description="")
- field_imm = Field(name="imm", base=[... | Fix encoding for J-type instructions The immediate (as well as being scattered crazily through the encoding!) has an offset of 1. | py |
diff --git a/kafka/consumer/group.py b/kafka/consumer/group.py
index <HASH>..<HASH> 100644
--- a/kafka/consumer/group.py
+++ b/kafka/consumer/group.py
@@ -116,7 +116,8 @@ class KafkaConsumer(six.Iterator):
rebalances. Default: 3000
session_timeout_ms (int): The timeout used to detect failures when... | Added doc for `max_poll_records` option (#<I>) | py |
diff --git a/openquake/calculators/event_based.py b/openquake/calculators/event_based.py
index <HASH>..<HASH> 100644
--- a/openquake/calculators/event_based.py
+++ b/openquake/calculators/event_based.py
@@ -44,7 +44,7 @@ F32 = numpy.float32
F64 = numpy.float64
TWO32 = 2 ** 32
RUPTURES_PER_BLOCK = 1000 # decided by ... | Changed weight [skip hazardlib] Former-commit-id: <I>a2a6a<I>be4e<I>f0ad1f<I>c2cfa3f<I> | py |
diff --git a/bdata/bdata.py b/bdata/bdata.py
index <HASH>..<HASH> 100644
--- a/bdata/bdata.py
+++ b/bdata/bdata.py
@@ -1249,10 +1249,6 @@ class bdata(mdata):
'sl_c': [ve][f] combined helicity.
"""
- # check rebin factor
- if type(rebin) not in (int, np.int64) or rebin <... | bdata.py: removed check on rebin. | py |
diff --git a/tests/integration/test_screenshots.py b/tests/integration/test_screenshots.py
index <HASH>..<HASH> 100644
--- a/tests/integration/test_screenshots.py
+++ b/tests/integration/test_screenshots.py
@@ -1,7 +1,6 @@
import os
import pytest
-import shutil
from selenium import webdriver
from selenium.common.... | test screenshots rm folder deleted | py |
diff --git a/openpnm/core/Base.py b/openpnm/core/Base.py
index <HASH>..<HASH> 100644
--- a/openpnm/core/Base.py
+++ b/openpnm/core/Base.py
@@ -265,7 +265,7 @@ class Base(dict):
keys = self.keys(mode='all', deep=True)
vals.update({k: self.interleave_data(k) for k in keys
... | tweaked __getitem__ to only update missing model if object has models attr | py |
diff --git a/fluent_dashboard/modules.py b/fluent_dashboard/modules.py
index <HASH>..<HASH> 100644
--- a/fluent_dashboard/modules.py
+++ b/fluent_dashboard/modules.py
@@ -75,8 +75,6 @@ class PersonalModule(modules.LinkList):
return False
-
-
class AppIconList(modules.AppList):
"""
The list of ap... | Fix icon_static_root fallback to MEDIA_URL | py |
diff --git a/spacy/sv/tokenizer_exceptions.py b/spacy/sv/tokenizer_exceptions.py
index <HASH>..<HASH> 100644
--- a/spacy/sv/tokenizer_exceptions.py
+++ b/spacy/sv/tokenizer_exceptions.py
@@ -4,6 +4,9 @@ from __future__ import unicode_literals
from ..symbols import *
from ..language_data import PRON_LEMMA
+
+EXC = {... | Add missing EXC variable and combine tokenizer exceptions | py |
diff --git a/docs/source/conf.py b/docs/source/conf.py
index <HASH>..<HASH> 100644
--- a/docs/source/conf.py
+++ b/docs/source/conf.py
@@ -65,11 +65,7 @@ author = u'Jason Shiverick'
# built documents.
#
# The short X.Y version.
-try:
- with open("../../RELEASE-VERSION", "r") as f:
- version = f.readlines()[0]
-e... | updated conf.py file in docs | py |
diff --git a/buku.py b/buku.py
index <HASH>..<HASH> 100755
--- a/buku.py
+++ b/buku.py
@@ -2757,7 +2757,7 @@ def piped_input(argv, pipeargs=None):
if not sys.stdin.isatty():
pipeargs += argv
print('waiting for input')
- for s in sys.stdin.readlines():
+ for s in sys.stdin:
... | Drop stdin.readlines(), treat as a file | py |
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -14,7 +14,7 @@ setup(
author = "Brian Brazil",
author_email = "brian.brazil@gmail.com",
description = ("Python client for the Prometheus monitoring system."),
- long_description = ("See https://github.com/bri... | Update setup.py to point to new repo. | py |
diff --git a/python/l20n/format/lol/parser.py b/python/l20n/format/lol/parser.py
index <HASH>..<HASH> 100644
--- a/python/l20n/format/lol/parser.py
+++ b/python/l20n/format/lol/parser.py
@@ -238,7 +238,7 @@ class Parser():
buffer += m.group(1)
self.content = self.content[m.end(0):]
... | do not play with unicode/ascii in a parser, it should be done on stream read/write | py |
diff --git a/tabular_predDB/HadoopEngine.py b/tabular_predDB/HadoopEngine.py
index <HASH>..<HASH> 100644
--- a/tabular_predDB/HadoopEngine.py
+++ b/tabular_predDB/HadoopEngine.py
@@ -21,7 +21,7 @@ import tabular_predDB.python_utils.general_utils as gu
import tabular_predDB.python_utils.xnet_utils as xu
-DEFAULT_CL... | change DEFAULT_CLUSTER back to highmem | py |
diff --git a/wagtailmodeladmin/helpers.py b/wagtailmodeladmin/helpers.py
index <HASH>..<HASH> 100644
--- a/wagtailmodeladmin/helpers.py
+++ b/wagtailmodeladmin/helpers.py
@@ -1,4 +1,3 @@
-from copy import copy
from django.contrib.auth import get_permission_codename
from django.utils.translation import ugettext as _
... | refactor delete button to avoid the need for copying of classname list | py |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.
diff --git a/tests/test_pwm.py b/tests/test_pwm.py
index <HASH>..<HASH> 100644
--- a/tests/test_pwm.py
+++ b/tests/test_pwm.py
@@ -38,7 +38,8 @@ def test_open_close():
assert pwm.chip == pwm_chip
assert pwm.channel == pwm_channel
- # Initialize duty cycle to 0
+ # Initialize period and duty cycle
+ ... | tests/pwm: initialize period before duty cycle this fixes running the test on a clean boot, where period and duty cycle are both 0. | py |